@@ -19,5 +19,5 @@
 
 from .anc_vars import dataset_walker, replace_anc  # noqa
 from .data_dict import DatasetDict, get_key  # noqa
-from .dataid import DataID, DataQuery, ModifierTuple, create_filtered_query  # noqa
+from .dataid import DataID, DataQuery, ModifierTuple, WavelengthRange, create_filtered_query  # noqa
 from .metadata import combine_metadata  # noqa
