@@ -31,7 +31,6 @@ import xarray as xr
 
 from satpy.dataset import DataID
 from satpy.scene import Scene
-from satpy.writers import get_enhanced_image, split_results
 
 try:
     import imageio
@@ -50,7 +49,7 @@ def _group_datasets_in_scenes(scenes, groups):
     """Group different datasets in multiple scenes by adding aliases.
 
     Args:
-        scenes (iterable): Scenes to be processed.
+        scenes (Iterable): Scenes to be processed.
         groups (dict): Groups of datasets that shall be treated equally by
             MultiScene. Keys specify the groups, values specify the dataset
             names to be grouped. For example::
@@ -163,7 +162,7 @@ class MultiScene(object):
         """Initialize MultiScene and validate sub-scenes.
 
         Args:
-            scenes (iterable):
+            scenes (Iterable):
                 `Scene` objects to operate on (optional)
 
         .. note::
@@ -209,9 +208,9 @@ class MultiScene(object):
                 readers have at least one file.  If False (default), include
                 all scenes where at least one reader has at least one file.
             scene_kwargs: additional arguments to pass on to
-                :func:`Scene.__init__` for each created scene.
+                :func:`satpy.scene.Scene.__init__` for each created scene.
 
-        This uses the :func:`satpy.readers.group_files` function to group
+        This uses the :func:`satpy.readers.core.grouping.group_files` function to group
         files. See this function for more details on additional possible
         keyword arguments.  In particular, it is strongly recommended to pass
         `"group_keys"` when using multiple instruments.
@@ -219,7 +218,7 @@ class MultiScene(object):
         .. versionadded:: 0.12
 
         """
-        from satpy.readers import group_files
+        from satpy.readers.core.grouping import group_files
         if scene_kwargs is None:
             scene_kwargs = {}
         file_groups = group_files(files_to_sort, reader=reader, **kwargs)
@@ -337,8 +336,9 @@ class MultiScene(object):
         dataset (:class:`xarray.DataArray` object).  The blend method
         then assigns those datasets to the blended scene.
 
-        Blending functions provided in this module are :func:`stack`
-        (the default), :func:`timeseries`, and :func:`temporal_rgb`, but the Python built-in
+        Blending functions provided in this module are :func:`satpy.multiscene._blend_funcs.stack`
+        (the default), :func:`satpy.multiscene._blend_funcs.timeseries`, and
+        :func:`satpy.multiscene._blend_funcs.temporal_rgb`, but the Python built-in
         function :func:`sum` also works and may be appropriate for
         some types of data.
 
@@ -350,7 +350,7 @@ class MultiScene(object):
         """
         if blend_function is None:
             # delay importing blend funcs until now in case they aren't used
-            from ._blend_funcs import stack
+            from .blend_funcs import stack
             blend_function = stack
 
         new_scn = Scene()
@@ -379,6 +379,8 @@ class MultiScene(object):
 
     def _distribute_save_datasets(self, scenes_iter, client, batch_size=1, **kwargs):
         """Distribute save_datasets across a cluster."""
+        from satpy.writers.core.compute import split_results
+
         def load_data(q):
             idx = 0
             while True:
@@ -400,7 +402,7 @@ class MultiScene(object):
 
         for scene in scenes_iter:
             delayeds = scene.save_datasets(compute=False, **kwargs)
-            sources, targets, delayeds = split_results(delayeds)
+            sources, targets, delayeds = split_results([delayeds])
             if len(sources) > 0:
                 # TODO Make this work for (source, target) datasets
                 # given a target, source combination
@@ -435,7 +437,7 @@ class MultiScene(object):
                 will attempt to process all scenes at once. This option should
                 be used with care to avoid memory issues when trying to
                 improve performance.
-            client (bool or dask.distributed.Client): Dask distributed client
+            client (bool or distributed.Client): Dask distributed client
                 to use for computation. If this is ``True`` (default) then
                 any existing clients will be used.
                 If this is ``False`` or ``None`` then a client will not be
@@ -460,6 +462,8 @@ class MultiScene(object):
 
     def _get_animation_info(self, all_datasets, filename, fill_value=None):
         """Determine filename and shape of animation to be created."""
+        from satpy.enhancements.enhancer import get_enhanced_image
+
         valid_datasets = [ds for ds in all_datasets if ds is not None]
         first_dataset = valid_datasets[0]
         last_dataset = valid_datasets[-1]
@@ -498,6 +502,8 @@ class MultiScene(object):
 
         Yet a single image frame from a dataset.
         """
+        from satpy.enhancements.enhancer import get_enhanced_image
+
         enh_args = enh_args.copy()  # don't change caller's dict!
         if "decorate" in enh_args:
             enh_args["decorate"] = self._format_decoration(
@@ -676,7 +682,7 @@ class MultiScene(object):
                 ``(batch_size / 2)`` frames for the second dataset.
             ignore_missing (bool): Don't include a black frame when a dataset
                                    is missing from a child scene.
-            client (bool or dask.distributed.Client): Dask distributed client
+            client (bool or distributed.Client): Dask distributed client
                 to use for computation. If this is ``True`` (default) then
                 any existing clients will be used.
                 If this is ``False`` or ``None`` then a client will not be
@@ -684,7 +690,7 @@ class MultiScene(object):
                 is a dask ``Client`` object then it will be used for
                 distributed computation.
             enh_args (Mapping): Optional, arguments passed to
-                :func:`satpy.writers.get_enhanced_image`.  If this includes a
+                :func:`satpy.enhancements.enhancer.get_enhanced_image`.  If this includes a
                 keyword "decorate", in any text added
                 to the image, string formatting will be applied based on
                 dataset attributes.  For example, passing
