@@ -29,14 +29,14 @@ import dask.array as da
 import numpy as np
 import xarray as xr
 
-from satpy.readers._geos_area import get_area_definition, get_geos_area_naming
-from satpy.readers.eum_base import get_service_mode
-from satpy.readers.fci_base import calculate_area_extent as fci_calculate_area_extent
-from satpy.readers.file_handlers import BaseFileHandler
-from satpy.readers.seviri_base import PLATFORM_DICT as SEVIRI_PLATFORM_DICT
-from satpy.readers.seviri_base import REPEAT_CYCLE_DURATION as SEVIRI_REPEAT_CYCLE_DURATION
-from satpy.readers.seviri_base import REPEAT_CYCLE_DURATION_RSS as SEVIRI_REPEAT_CYCLE_DURATION_RSS
-from satpy.readers.seviri_base import calculate_area_extent as seviri_calculate_area_extent
+from satpy.readers.core._geos_area import get_area_definition, get_geos_area_naming
+from satpy.readers.core.eum import get_service_mode
+from satpy.readers.core.fci import calculate_area_extent as fci_calculate_area_extent
+from satpy.readers.core.file_handlers import BaseFileHandler
+from satpy.readers.core.seviri import PLATFORM_DICT as SEVIRI_PLATFORM_DICT
+from satpy.readers.core.seviri import REPEAT_CYCLE_DURATION as SEVIRI_REPEAT_CYCLE_DURATION
+from satpy.readers.core.seviri import REPEAT_CYCLE_DURATION_RSS as SEVIRI_REPEAT_CYCLE_DURATION_RSS
+from satpy.readers.core.seviri import calculate_area_extent as seviri_calculate_area_extent
 from satpy.utils import get_legacy_chunk_size
 
 CHUNK_SIZE = get_legacy_chunk_size()
@@ -271,7 +271,7 @@ class EUML2GribFileHandler(BaseFileHandler):
             gid: The ID of the GRIB message.
 
         Returns:
-            DataArray: The array containing the retrieved values.
+            The DataArray containing the retrieved values.
         """
         # Data from GRIB message are read into an Xarray...
         xarr = xr.DataArray(da.from_array(ec.codes_get_values(
