@@ -37,7 +37,7 @@ import numpy as np
 from pyproj import Proj
 from pyresample import geometry
 
-from satpy.readers.netcdf_utils import NetCDF4FileHandler, netCDF4
+from satpy.readers.core.netcdf import NetCDF4FileHandler, netCDF4
 
 LOG = logging.getLogger(__name__)
 
@@ -168,7 +168,7 @@ class GEOCATFileHandler(NetCDF4FileHandler):
         information down the chain.
 
         See
-        :meth:`satpy.readers.file_handlers.BaseFileHandler.available_datasets`
+        :meth:`satpy.readers.core.file_handlers.BaseFileHandler.available_datasets`
         for details.
 
         """
