@@ -25,7 +25,7 @@ import logging
 import numpy as np
 
 from satpy.dataset import Dataset
-from satpy.readers.netcdf_utils import NetCDF4FileHandler
+from satpy.readers.core.netcdf import NetCDF4FileHandler
 
 logger = logging.getLogger(__name__)
 
