@@ -233,9 +233,9 @@ import numpy as np
 import pyresample.geometry
 import xarray as xr
 
-from satpy.readers.file_handlers import BaseFileHandler
+from satpy.readers.core.file_handlers import BaseFileHandler
+from satpy.readers.core.utils import bbox, get_geostationary_angle_extent
 from satpy.readers.goes_imager_hrit import ALTITUDE, EQUATOR_RADIUS, POLE_RADIUS, SPACECRAFTS
-from satpy.readers.utils import bbox, get_geostationary_angle_extent
 from satpy.utils import get_legacy_chunk_size
 
 logger = logging.getLogger(__name__)
@@ -976,7 +976,7 @@ class GOESNCBaseFileHandler(BaseFileHandler):
         information down the chain.
 
         See
-        :meth:`satpy.readers.file_handlers.BaseFileHandler.available_datasets`
+        :meth:`satpy.readers.core.file_handlers.BaseFileHandler.available_datasets`
         for details.
         """
         res = self.resolution
@@ -1352,7 +1352,7 @@ def test_coefs(ir_url, vis_url):
         vis_url: Path or URL to HTML page with VIS coefficients
 
     Raises:
-        ValueError if coefficients don't match the reference
+        (Exception) ValueError: if coefficients don't match the reference
     """
     reader = GOESCoefficientReader(ir_url=ir_url, vis_url=vis_url)
 
