@@ -32,7 +32,7 @@ import h5py
 import numpy as np
 from pyresample.geometry import AreaDefinition
 
-from satpy.readers.hdf5_utils import HDF5FileHandler
+from satpy.readers.core.hdf5 import HDF5FileHandler
 
 logger = logging.getLogger(__name__)
 
