@@ -76,8 +76,8 @@ import logging
 import numpy as np
 import xarray as xr
 
-from satpy.readers.hdf4_utils import from_sds
-from satpy.readers.hdfeos_base import HDFEOSBaseFileReader, HDFEOSGeoReader
+from satpy.readers.core.hdf4 import from_sds
+from satpy.readers.core.hdfeos import HDFEOSBaseFileReader, HDFEOSGeoReader
 
 logger = logging.getLogger(__name__)
 
