@@ -108,10 +108,10 @@ import xarray as xr
 from pyresample import geometry
 
 from satpy._compat import cached_property
-from satpy.readers._geos_area import get_area_definition, get_geos_area_naming
-from satpy.readers.eum_base import get_service_mode, recarray2dict, time_cds_short
-from satpy.readers.file_handlers import BaseFileHandler
-from satpy.readers.seviri_base import (
+from satpy.readers.core._geos_area import get_area_definition, get_geos_area_naming
+from satpy.readers.core.eum import get_service_mode, recarray2dict, time_cds_short
+from satpy.readers.core.file_handlers import BaseFileHandler
+from satpy.readers.core.seviri import (
     CHANNEL_NAMES,
     HRV_NUM_COLUMNS,
     HRV_NUM_LINES,
@@ -137,13 +137,13 @@ from satpy.readers.seviri_base import (
     pad_data_vertically,
     round_nom_time,
 )
+from satpy.readers.core.utils import fromfile, generic_open, reduce_mda
 from satpy.readers.seviri_l1b_native_hdr import (
     DEFAULT_15_SECONDARY_PRODUCT_HEADER,
     GSDTRecords,
     get_native_header,
     native_trailer,
 )
-from satpy.readers.utils import fromfile, generic_open, reduce_mda
 from satpy.utils import get_legacy_chunk_size
 
 logger = logging.getLogger("native_msg")
@@ -156,7 +156,7 @@ class NativeMSGFileHandler(BaseFileHandler):
 
     **Calibration**
 
-    See :mod:`satpy.readers.seviri_base`.
+    See :mod:`satpy.readers.core.seviri`.
 
     **Padding channel data to full disk**
 
@@ -171,7 +171,7 @@ class NativeMSGFileHandler(BaseFileHandler):
 
     **Metadata**
 
-    See :mod:`satpy.readers.seviri_base`.
+    See :mod:`satpy.readers.core.seviri`.
 
     """
 
