@@ -23,10 +23,10 @@ import logging
 import numpy as np
 
 from satpy._compat import cached_property
-from satpy.readers._geos_area import get_area_definition, get_geos_area_naming
-from satpy.readers.eum_base import get_service_mode
-from satpy.readers.file_handlers import BaseFileHandler, open_dataset
-from satpy.readers.seviri_base import (
+from satpy.readers.core._geos_area import get_area_definition, get_geos_area_naming
+from satpy.readers.core.eum import get_service_mode
+from satpy.readers.core.file_handlers import BaseFileHandler, open_dataset
+from satpy.readers.core.seviri import (
     CHANNEL_NAMES,
     SATNUM,
     CalibParams,
@@ -53,13 +53,13 @@ class NCSEVIRIFileHandler(BaseFileHandler):
 
     **Calibration**
 
-    See :mod:`satpy.readers.seviri_base`. Note that there is only one set of
+    See :mod:`satpy.readers.core.seviri`. Note that there is only one set of
     calibration coefficients available in the netCDF files and therefore there
     is no `calib_mode` argument.
 
     **Metadata**
 
-    See :mod:`satpy.readers.seviri_base`.
+    See :mod:`satpy.readers.core.seviri`.
 
     """
 
@@ -175,7 +175,7 @@ class NCSEVIRIFileHandler(BaseFileHandler):
 
         dataset = self.calibrate(dataset, dataset_id)
         is_calibration = dataset_id["calibration"] in ["radiance", "reflectance", "brightness_temperature"]
-        if (is_calibration and self.mask_bad_quality_scan_lines):  # noqa: E129
+        if (is_calibration and self.mask_bad_quality_scan_lines):
             dataset = self._mask_bad_quality(dataset, dataset_info)
 
         self._update_attrs(dataset, dataset_info)
