@@ -24,8 +24,9 @@ ASCII files.
 import dask.dataframe as dd
 import xarray as xr
 
-from satpy.readers.file_handlers import BaseFileHandler
-from satpy.readers.netcdf_utils import NetCDF4FileHandler
+from satpy.dataset.dataid import DataID
+from satpy.readers.core.file_handlers import BaseFileHandler
+from satpy.readers.core.netcdf import NetCDF4FileHandler
 
 # map platform attributes to Oscar standard name
 PLATFORM_MAP = {
@@ -46,15 +47,15 @@ class VIIRSActiveFiresFileHandler(NetCDF4FileHandler):
             auto_maskandscale=auto_maskandscale, xarray_kwargs=xarray_kwargs)
         self.prefix = filetype_info.get("variable_prefix")
 
-    def get_dataset(self, dsid, dsinfo):  # noqa: D417
+    def get_dataset(self, dsid: DataID, dsinfo: dict) -> xr.DataArray:  # noqa: D417
         """Get requested data as DataArray.
 
         Args:
-            dsid: Dataset ID
-            param2: Dataset Information
+            dsid: DataID to load data for
+            dsinfo: Dataset information
 
         Returns:
-            Dask DataArray: Data
+            DataArray of the loaded variable
 
         """
         key = dsinfo.get("file_key", dsid["name"]).format(variable_prefix=self.prefix)
