@@ -22,7 +22,7 @@ import logging
 
 import numpy as np
 
-from satpy.readers.netcdf_utils import NetCDF4FileHandler
+from satpy.readers.core.netcdf import NetCDF4FileHandler
 
 LOG = logging.getLogger(__name__)
 
@@ -182,12 +182,18 @@ class VIIRSL1BFileHandler(NetCDF4FileHandler):
         i = getattr(self[var_path], "attrs", {})
         i.update(ds_info)
         i.update(dataset_id.to_dict())
+        orb_param = {"start_direction": self["/attr/startDirection"],
+                     "end_direction": self["/attr/endDirection"],
+                     "start_orbit": self.start_orbit_number,
+                     "end_orbit": self.end_orbit_number,}
         i.update({
             "shape": shape,
             "units": ds_info.get("units", file_units),
             "file_units": file_units,
             "platform_name": self.platform_name,
             "sensor": self.sensor_name,
+            "day_night": self["/attr/DayNightFlag"],
+            "orbital_parameters": orb_param,
             "start_orbit": self.start_orbit_number,
             "end_orbit": self.end_orbit_number,
         })
@@ -235,6 +241,11 @@ class VIIRSL1BFileHandler(NetCDF4FileHandler):
         if factors[0] != 1 or factors[1] != 0:
             data *= factors[0]
             data += factors[1]
+
+        # remove scale_factor and scale_offset
+        data.attrs.pop("scale_factor", None)
+        data.attrs.pop("add_offset", None)
+
         # rename dimensions to correspond to satpy's 'y' and 'x' standard
         if "number_of_lines" in data.dims:
             data = data.rename({"number_of_lines": "y", "number_of_pixels": "x"})
@@ -244,7 +255,7 @@ class VIIRSL1BFileHandler(NetCDF4FileHandler):
         """Generate dataset info and their availablity.
 
         See
-        :meth:`satpy.readers.file_handlers.BaseFileHandler.available_datasets`
+        :meth:`satpy.readers.core.file_handlers.BaseFileHandler.available_datasets`
         for details.
 
         """
@@ -260,6 +271,26 @@ class VIIRSL1BFileHandler(NetCDF4FileHandler):
             is_in_file = var_path in self
             yield ft_matches and is_in_file, ds_info
 
+            # Handle the _quality_flags dataset
+            qf_name = ds_info["name"] + "_quality_flags"
+
+            # Create a copy and override file_key if not explicitly provided
+            qf_ds_info = ds_info.copy()
+            qf_ds_info["name"] = qf_name
+            qf_ds_info["file_key"] = f"observation_data/{qf_name}"
+            qf_var_path = self._dataset_name_to_var_path(qf_name, qf_ds_info)
+
+            if qf_var_path in self:
+                qf_info = {
+                    "name": qf_name,
+                    "file_type": ds_info["file_type"],
+                    "resolution": ds_info.get("resolution"),
+                    "coordinates": ds_info.get("coordinates") or [],
+                    "units": "1",
+                    "standard_name": "quality_flag",
+                }
+                yield True, qf_info
+
     @staticmethod
     def _dataset_name_to_var_path(dataset_name: str, ds_info: dict) -> str:
         return ds_info.get("file_key", "observation_data/{}".format(dataset_name))
