@@ -20,6 +20,7 @@
 import datetime  # noqa: I001
 import os
 
+import netCDF4
 import numpy as np
 import pytest
 import xarray as xr
@@ -113,7 +114,7 @@ def fake_files(fake_dataset, encoding, tmp_path):
 def reader():
     """Return reader for CMSAF CLAAS-2."""
     from satpy._config import config_search_paths
-    from satpy.readers import load_reader
+    from satpy.readers.core.loading import load_reader
 
     reader_configs = config_search_paths(
         os.path.join("readers", "cmsaf-claas2_l2_nc.yaml"))
@@ -183,39 +184,6 @@ class TestCLAAS2SingleFile:
         from satpy.readers.cmsaf_claas2 import CLAAS2
         return CLAAS2(fake_file, {}, {})
 
-    @pytest.fixture
-    def area_extent_exp(self, start_time):
-        """Get expected area extent."""
-        if start_time < datetime.datetime(2017, 12, 6):
-            return (-5454733.160460291, -5454733.160460292, 5454733.160460292, 5454733.160460291)
-        return (-5456233.362099582, -5453232.958821001, 5453232.958821001, 5456233.362099582)
-
-    @pytest.fixture
-    def area_exp(self, area_extent_exp):
-        """Get expected area definition."""
-        proj_dict = {
-            "a": 6378169.0,
-            "b": 6356583.8,
-            "h": 35785831.0,
-            "lon_0": 0.0,
-            "proj": "geos",
-            "units": "m",
-        }
-        return AreaDefinition(
-            area_id="msg_seviri_fes_3km",
-            description="MSG SEVIRI Full Earth Scanning service area definition with 3 km resolution",
-            proj_id="geos",
-            projection=proj_dict,
-            area_extent=area_extent_exp,
-            width=3636,
-            height=3636,
-        )
-
-    def test_get_area_def(self, file_handler, area_exp):
-        """Test area definition."""
-        area = file_handler.get_area_def(make_dataid(name="foo"))
-        assert area == area_exp
-
     @pytest.mark.parametrize(
         ("ds_name", "expected"),
         [
@@ -236,3 +204,71 @@ class TestCLAAS2SingleFile:
     def test_end_time(self, file_handler):
         """Test end time property."""
         assert file_handler.end_time == datetime.datetime(2085, 8, 13, 13, 15)
+
+class TestAreaDef:
+    """Test the area of both CLAAS2 and CLAAS3 products."""
+    @pytest.fixture(params=[3636, 3712])
+    def grid_size(self, request):
+        """Return the grid size."""
+        return request.param
+
+    @pytest.fixture
+    def fake_file(self, tmp_path, start_time_str, grid_size):
+        """Write a fake dataset to file.
+
+        Only add y dimension, so that the file is small but we can still check the
+        real-life area definition.
+        """
+        filename = tmp_path / "CPPin20140101001500305SVMSG01MD.nc"
+        ds = netCDF4.Dataset(filename, mode="w")
+        ds.createDimension("y", grid_size)
+        ds.setncattr("time_coverage_start", start_time_str)
+        ds.close()
+        return filename
+
+    @pytest.fixture
+    def file_handler(self, fake_file):
+        """Return a CLAAS-2 file handler."""
+        from satpy.readers.cmsaf_claas2 import CLAAS2
+        return CLAAS2(fake_file, {}, {})
+
+    @pytest.fixture
+    def area_extent_exp(self, start_time, grid_size):
+        """Get expected area extent."""
+        if start_time < datetime.datetime(2017, 12, 6):
+            extents = {
+                3636: (-5454733.160460291, -5454733.160460292, 5454733.160460292, 5454733.160460291),
+                3712: (-5568748.485046371, -5568748.485046371, 5568748.485046371, 5568748.485046371)
+            }
+        else:
+            extents = {
+                3636: (-5456233.362099582, -5453232.958821001, 5453232.958821001, 5456233.362099582),
+                3712: (-5570248.686685662, -5567248.28340708, 5567248.28340708, 5570248.686685662)
+            }
+        return extents[grid_size]
+
+    @pytest.fixture
+    def area_exp(self, area_extent_exp, grid_size):
+        """Get expected area definition."""
+        proj_dict = {
+            "a": 6378169.0,
+            "b": 6356583.8,
+            "h": 35785831.0,
+            "lon_0": 0.0,
+            "proj": "geos",
+            "units": "m",
+        }
+        return AreaDefinition(
+            area_id="msg_seviri_fes_3km",
+            description="MSG SEVIRI Full Earth Scanning service area definition with 3 km resolution",
+            proj_id="geos",
+            projection=proj_dict,
+            area_extent=area_extent_exp,
+            width=grid_size,
+            height=grid_size,
+        )
+
+    def test_get_area_def(self, file_handler, area_exp):
+        """Test area definition."""
+        area = file_handler.get_area_def(make_dataid(name="foo"))
+        assert area == area_exp
