@@ -21,7 +21,7 @@ from unittest import mock
 
 import pytest
 
-from satpy.readers.fy4_base import FY4Base
+from satpy.readers.core.fy4 import FY4Base
 from satpy.tests.reader_tests.test_agri_l1 import FakeHDF5FileHandler2
 
 
