@@ -123,9 +123,11 @@ def gerb_l2_hr_h5_dummy_file(tmp_path_factory):
 
 @pytest.mark.xfail(xfail_h5py_unstable_numpy2(), reason="h5py doesn't include numpy 2 fix")
 @pytest.mark.parametrize("name", ["Solar Flux", "Thermal Flux", "Solar Radiance", "Thermal Radiance"])
-def test_dataset_load(gerb_l2_hr_h5_dummy_file, name):
+@pytest.mark.parametrize("area", [None, "msg_seviri_iodc_9km"])
+def test_dataset_load(gerb_l2_hr_h5_dummy_file, name, area):
     """Test loading the solar flux component."""
-    scene = Scene(reader="gerb_l2_hr_h5", filenames=[gerb_l2_hr_h5_dummy_file])
+    scene = Scene(reader="gerb_l2_hr_h5", filenames=[gerb_l2_hr_h5_dummy_file],
+                  reader_kwargs={"area": area})
     scene.load([name])
     assert scene[name].shape == (1237, 1237)
     assert np.nanmax((scene[name].to_numpy().flatten() - 0.25)) < 1e-6
