@@ -22,13 +22,10 @@ import unittest
 from unittest import mock
 
 import numpy as np
-from pyresample.utils import proj4_radius_parameters
 from xarray import DataArray
 
 from satpy.readers.goes_imager_hrit import (
     ALTITUDE,
-    EQUATOR_RADIUS,
-    POLE_RADIUS,
     HRITGOESFileHandler,
     HRITGOESPrologueFileHandler,
     make_gvar_float,
@@ -172,6 +169,8 @@ class TestHRITGOESFileHandler(unittest.TestCase):
 
     def test_get_area_def(self):
         """Test getting the area definition."""
+        from pyproj import CRS
+
         self.reader.mda.update({
             "cfac": 10216334,
             "lfac": 10216334,
@@ -184,13 +183,10 @@ class TestHRITGOESFileHandler(unittest.TestCase):
                            resolution=3000)
         area = self.reader.get_area_def(dsid)
 
-        a, b = proj4_radius_parameters(area.proj_dict)
-        assert a == EQUATOR_RADIUS
-        assert b == POLE_RADIUS
-        assert area.proj_dict["h"] == ALTITUDE
-        assert area.proj_dict["lon_0"] == 100.1640625
-        assert area.proj_dict["proj"] == "geos"
-        assert area.proj_dict["units"] == "m"
+        expected_crs = CRS(dict(h=ALTITUDE, lon_0=100.1640625, proj="geos", units="m",
+                                rf=295.488065897001, a=6378169))
+        assert area.crs == expected_crs
+
         assert area.width == 2816
         assert area.height == 464
         assert area.area_id == "goes-15_goes_imager_fd_3km"
