@@ -106,7 +106,7 @@ class TestMimicTPW2Reader(unittest.TestCase):
 
     def test_init(self):
         """Test basic initialization of this reader."""
-        from satpy.readers import load_reader
+        from satpy.readers.core.loading import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
             "comp20190619.130000.nc",
@@ -118,7 +118,7 @@ class TestMimicTPW2Reader(unittest.TestCase):
 
     def test_load_mimic(self):
         """Load Mimic data."""
-        from satpy.readers import load_reader
+        from satpy.readers.core.loading import load_reader
         r = load_reader(self.reader_configs)
         with mock.patch("satpy.readers.mimic_TPW2_nc.netCDF4.Variable", xr.DataArray):
             loadables = r.select_files_from_pathnames([
