@@ -29,7 +29,7 @@ import pytest
 import xarray as xr
 from netCDF4 import Dataset
 
-from satpy.readers.vii_base_nc import SCAN_ALT_TIE_POINTS, TIE_POINTS_FACTOR, ViiNCBaseFileHandler
+from satpy.readers.core.vii_nc import SCAN_ALT_TIE_POINTS, TIE_POINTS_FACTOR, ViiNCBaseFileHandler
 
 TEST_FILE = "test_file_vii_base_nc.nc"
 
@@ -37,7 +37,7 @@ TEST_FILE = "test_file_vii_base_nc.nc"
 class TestViiNCBaseFileHandler(unittest.TestCase):
     """Test the ViiNCBaseFileHandler reader."""
 
-    @mock.patch("satpy.readers.vii_base_nc.ViiNCBaseFileHandler._perform_geo_interpolation")
+    @mock.patch("satpy.readers.core.vii_nc.ViiNCBaseFileHandler._perform_geo_interpolation")
     def setUp(self, pgi_):
         """Set up the test."""
         # Easiest way to test the reader is to create a test netCDF file on the fly
@@ -215,8 +215,8 @@ class TestViiNCBaseFileHandler(unittest.TestCase):
                         equal = global_attributes[key][inner_key] == expected_global_attributes[key][inner_key]
                     assert equal
 
-    @mock.patch("satpy.readers.vii_base_nc.tie_points_interpolation")
-    @mock.patch("satpy.readers.vii_base_nc.tie_points_geo_interpolation")
+    @mock.patch("satpy.readers.core.vii_nc.tie_points_interpolation")
+    @mock.patch("satpy.readers.core.vii_nc.tie_points_geo_interpolation")
     def test_functions(self, tpgi_, tpi_):
         """Test the functions."""
         with pytest.raises(NotImplementedError):
@@ -309,9 +309,9 @@ class TestViiNCBaseFileHandler(unittest.TestCase):
         assert out_variable.dims == ("y", "x")
         assert out_variable.attrs["key_1"] == "value_lat_1"
 
-    @mock.patch("satpy.readers.vii_base_nc.ViiNCBaseFileHandler._perform_calibration")
-    @mock.patch("satpy.readers.vii_base_nc.ViiNCBaseFileHandler._perform_interpolation")
-    @mock.patch("satpy.readers.vii_base_nc.ViiNCBaseFileHandler._perform_orthorectification")
+    @mock.patch("satpy.readers.core.vii_nc.ViiNCBaseFileHandler._perform_calibration")
+    @mock.patch("satpy.readers.core.vii_nc.ViiNCBaseFileHandler._perform_interpolation")
+    @mock.patch("satpy.readers.core.vii_nc.ViiNCBaseFileHandler._perform_orthorectification")
     def test_dataset(self, po_, pi_, pc_):
         """Test the execution of the get_dataset function."""
         # Checks the correct execution of the get_dataset function with a valid file_key
