@@ -20,7 +20,7 @@
 
 import unittest
 
-import satpy.readers.vii_utils
+import satpy.readers.core.vii
 
 # Constants to be tested
 C1 = 1.191062e+8
@@ -36,8 +36,8 @@ class TestViiUtils(unittest.TestCase):
     def test_constants(self):
         """Test the constant values."""
         # Test the value of the constants
-        assert satpy.readers.vii_utils.C1 == C1
-        assert satpy.readers.vii_utils.C2 == C2
-        assert satpy.readers.vii_utils.TIE_POINTS_FACTOR == TIE_POINTS_FACTOR
-        assert satpy.readers.vii_utils.SCAN_ALT_TIE_POINTS == SCAN_ALT_TIE_POINTS
-        assert satpy.readers.vii_utils.MEAN_EARTH_RADIUS == MEAN_EARTH_RADIUS
+        assert satpy.readers.core.vii.C1 == C1
+        assert satpy.readers.core.vii.C2 == C2
+        assert satpy.readers.core.vii.TIE_POINTS_FACTOR == TIE_POINTS_FACTOR
+        assert satpy.readers.core.vii.SCAN_ALT_TIE_POINTS == SCAN_ALT_TIE_POINTS
+        assert satpy.readers.core.vii.MEAN_EARTH_RADIUS == MEAN_EARTH_RADIUS
