@@ -20,6 +20,7 @@
 import os
 
 import numpy as np
+import pytest
 
 from satpy import Scene
 from satpy.tests.reader_tests.test_viirs_compact import fake_dnb, fake_dnb_file  # noqa
@@ -29,6 +30,9 @@ from satpy.tests.reader_tests.test_viirs_compact import fake_dnb, fake_dnb_file
 # - tmp_path
 
 
+# ignore that the "coordinates" added by the reader aren't found in the existing list of variables
+# the correct lon/lat coordinates are listed in the final netcdf file
+@pytest.mark.filterwarnings("ignore:Coordinate .*itude_dnb.* referenced by dataarray DNB:UserWarning")
 def test_cf_roundtrip(fake_dnb_file, tmp_path):  # noqa
     """Test the cf writing reading cycle."""
     dnb_filename = os.fspath(fake_dnb_file)
