@@ -48,7 +48,7 @@ class UnfriendlyModifier(ModifierBase, DataDownloadMixin):
 
 
 def _setup_custom_composite_config(base_dir):
-    from satpy.composites import StaticImageCompositor
+    from satpy.composites.aux_data import StaticImageCompositor
     from satpy.modifiers.atmosphere import ReflectanceCorrector
     composite_config = base_dir.mkdir("composites").join("visir.yaml")
     with open(composite_config, "w") as comp_file:
@@ -84,7 +84,7 @@ def _setup_custom_reader_config(base_dir):
         comp_file.write("""
 reader:
   name: "fake"
-  reader: !!python/name:satpy.readers.yaml_reader.FileYAMLReader
+  reader: !!python/name:satpy.readers.core.yaml_reader.FileYAMLReader
   data_files:
     - url: {}
       known_hash: null
@@ -102,7 +102,7 @@ def _setup_custom_writer_config(base_dir):
         comp_file.write("""
 writer:
   name: "fake"
-  writer: !!python/name:satpy.writers.Writer
+  writer: !!python/name:satpy.writers.core.base.Writer
   data_files:
     - url: {}
       known_hash: null
