@@ -293,6 +293,22 @@ class TestCombineMetadata(unittest.TestCase):
         result = combine_metadata(*test_metadata)
         assert "valid_range" not in result
 
+    def test_combine_xarray_arrays(self):
+        """Test combining values that are non daskified xarray dataArrays."""
+        import xarray as xr
+
+        from satpy.dataset.metadata import combine_metadata
+
+        test_metadata = [{"valid_range": xr.DataArray(np.array([0., 0.00032], dtype=np.float32),
+                         attrs={"_FillValue": -9999})},
+                         {"valid_range": xr.DataArray(np.array([0., 0.00032], dtype=np.float32),
+                         attrs={"_FillValue": -9999})},
+                         {"valid_range": xr.DataArray(np.array([0., 0.00032], dtype=np.float32),
+                         attrs={"_FillValue": -9999})}]
+        result = combine_metadata(*test_metadata)
+        assert np.allclose(result["valid_range"], xr.DataArray(np.array([0., 0.00032], dtype=np.float32),
+                         attrs={"_FillValue": -9999}))
+
     def test_combine_real_world_mda(self):
         """Test with real data."""
         mda_objects = ({"_FillValue": np.nan,
