@@ -27,6 +27,8 @@ import unittest
 from collections import defaultdict
 from unittest import mock
 
+import pytest
+
 # NOTE:
 # The following fixtures are not defined in this file, but are used and injected by Pytest:
 # - tmp_path
@@ -58,7 +60,7 @@ class _GlobHelper(object):
         except IndexError:
             num_results = self.num_results[-1]
         self.current_call += 1
-        return [pattern + '.{:03d}'.format(idx) for idx in range(num_results)]
+        return [pattern + ".{:03d}".format(idx) for idx in range(num_results)]
 
 
 class TestDemo(unittest.TestCase):
@@ -80,26 +82,28 @@ class TestDemo(unittest.TestCase):
         except OSError:
             pass
 
-    @mock.patch('satpy.demo._google_cloud_platform.gcsfs')
+    @mock.patch("satpy.demo._google_cloud_platform.gcsfs")
     def test_get_us_midlatitude_cyclone_abi(self, gcsfs_mod):
         """Test data download function."""
         from satpy.demo import get_us_midlatitude_cyclone_abi
         gcsfs_mod.GCSFileSystem = mock.MagicMock()
         gcsfs_inst = mock.MagicMock()
         gcsfs_mod.GCSFileSystem.return_value = gcsfs_inst
-        gcsfs_inst.glob.return_value = ['a.nc', 'b.nc']
+        gcsfs_inst.glob.return_value = ["a.nc", "b.nc"]
         # expected 16 files, got 2
-        self.assertRaises(AssertionError, get_us_midlatitude_cyclone_abi)
+        with pytest.raises(RuntimeError):
+            get_us_midlatitude_cyclone_abi()
         # unknown access method
-        self.assertRaises(NotImplementedError, get_us_midlatitude_cyclone_abi, method='unknown')
+        with pytest.raises(NotImplementedError):
+            get_us_midlatitude_cyclone_abi(method="unknown")
 
-        gcsfs_inst.glob.return_value = ['a.nc'] * 16
+        gcsfs_inst.glob.return_value = ["a.nc"] * 16
         filenames = get_us_midlatitude_cyclone_abi()
-        expected = os.path.join('.', 'abi_l1b', '20190314_us_midlatitude_cyclone', 'a.nc')
+        expected = os.path.join(".", "abi_l1b", "20190314_us_midlatitude_cyclone", "a.nc")
         for fn in filenames:
-            self.assertEqual(expected, fn)
+            assert expected == fn
 
-    @mock.patch('satpy.demo._google_cloud_platform.gcsfs')
+    @mock.patch("satpy.demo._google_cloud_platform.gcsfs")
     def test_get_hurricane_florence_abi(self, gcsfs_mod):
         """Test data download function."""
         from satpy.demo import get_hurricane_florence_abi
@@ -109,86 +113,91 @@ class TestDemo(unittest.TestCase):
         # only return 5 results total
         gcsfs_inst.glob.side_effect = _GlobHelper([5, 0])
         # expected 16 files * 10 frames, got 16 * 5
-        self.assertRaises(AssertionError, get_hurricane_florence_abi)
-        self.assertRaises(NotImplementedError, get_hurricane_florence_abi, method='unknown')
+        with pytest.raises(RuntimeError):
+            get_hurricane_florence_abi()
+        with pytest.raises(NotImplementedError):
+            get_hurricane_florence_abi(method="unknown")
 
         gcsfs_inst.glob.side_effect = _GlobHelper([int(240 / 16), 0, 0, 0] * 16)
         filenames = get_hurricane_florence_abi()
-        self.assertEqual(10 * 16, len(filenames))
+        assert 10 * 16 == len(filenames)
 
         gcsfs_inst.glob.side_effect = _GlobHelper([int(240 / 16), 0, 0, 0] * 16)
         filenames = get_hurricane_florence_abi(channels=[2, 3, 4])
-        self.assertEqual(10 * 3, len(filenames))
+        assert 10 * 3 == len(filenames)
 
         gcsfs_inst.glob.side_effect = _GlobHelper([int(240 / 16), 0, 0, 0] * 16)
         filenames = get_hurricane_florence_abi(channels=[2, 3, 4], num_frames=5)
-        self.assertEqual(5 * 3, len(filenames))
+        assert 5 * 3 == len(filenames)
 
         gcsfs_inst.glob.side_effect = _GlobHelper([int(240 / 16), 0, 0, 0] * 16)
         filenames = get_hurricane_florence_abi(num_frames=5)
-        self.assertEqual(5 * 16, len(filenames))
+        assert 5 * 16 == len(filenames)
 
 
 class TestGCPUtils(unittest.TestCase):
     """Test Google Cloud Platform utilities."""
 
-    @mock.patch('satpy.demo._google_cloud_platform.urlopen')
+    @mock.patch("satpy.demo._google_cloud_platform.urlopen")
     def test_is_gcp_instance(self, uo):
         """Test is_google_cloud_instance."""
         from satpy.demo._google_cloud_platform import URLError, is_google_cloud_instance
         uo.side_effect = URLError("Test Environment")
-        self.assertFalse(is_google_cloud_instance())
+        assert not is_google_cloud_instance()
 
-    @mock.patch('satpy.demo._google_cloud_platform.gcsfs')
+    @mock.patch("satpy.demo._google_cloud_platform.gcsfs")
     def test_get_bucket_files(self, gcsfs_mod):
         """Test get_bucket_files basic cases."""
         from satpy.demo._google_cloud_platform import get_bucket_files
         gcsfs_mod.GCSFileSystem = mock.MagicMock()
         gcsfs_inst = mock.MagicMock()
         gcsfs_mod.GCSFileSystem.return_value = gcsfs_inst
-        gcsfs_inst.glob.return_value = ['a.nc', 'b.nc']
-        filenames = get_bucket_files('*.nc', '.')
-        expected = [os.path.join('.', 'a.nc'), os.path.join('.', 'b.nc')]
-        self.assertEqual(expected, filenames)
+        gcsfs_inst.glob.return_value = ["a.nc", "b.nc"]
+        filenames = get_bucket_files("*.nc", ".")
+        expected = [os.path.join(".", "a.nc"), os.path.join(".", "b.nc")]
+        assert expected == filenames
 
         gcsfs_inst.glob.side_effect = _GlobHelper(10)
-        filenames = get_bucket_files(['*.nc', '*.txt'], '.', pattern_slice=slice(2, 5))
-        self.assertEqual(len(filenames), 3 * 2)
+        filenames = get_bucket_files(["*.nc", "*.txt"], ".", pattern_slice=slice(2, 5))
+        assert len(filenames) == 3 * 2
         gcsfs_inst.glob.side_effect = None  # reset mock side effect
 
-        gcsfs_inst.glob.return_value = ['a.nc', 'b.nc']
-        self.assertRaises(OSError, get_bucket_files, '*.nc', 'does_not_exist')
+        gcsfs_inst.glob.return_value = ["a.nc", "b.nc"]
+        with pytest.raises(OSError, match="Directory does not exist: does_not_exist"):
+            get_bucket_files("*.nc", "does_not_exist")
 
-        open('a.nc', 'w').close()  # touch the file
+        open("a.nc", "w").close()  # touch the file
         gcsfs_inst.get.reset_mock()
-        gcsfs_inst.glob.return_value = ['a.nc']
-        filenames = get_bucket_files('*.nc', '.')
-        self.assertEqual([os.path.join('.', 'a.nc')], filenames)
+        gcsfs_inst.glob.return_value = ["a.nc"]
+        filenames = get_bucket_files("*.nc", ".")
+        assert [os.path.join(".", "a.nc")] == filenames
         gcsfs_inst.get.assert_not_called()
 
         # force redownload
         gcsfs_inst.get.reset_mock()
-        gcsfs_inst.glob.return_value = ['a.nc']
-        filenames = get_bucket_files('*.nc', '.', force=True)
-        self.assertEqual([os.path.join('.', 'a.nc')], filenames)
+        gcsfs_inst.glob.return_value = ["a.nc"]
+        filenames = get_bucket_files("*.nc", ".", force=True)
+        assert [os.path.join(".", "a.nc")] == filenames
         gcsfs_inst.get.assert_called_once()
 
         # if we don't get any results then we expect an exception
         gcsfs_inst.get.reset_mock()
         gcsfs_inst.glob.return_value = []
-        self.assertRaises(OSError, get_bucket_files, '*.nc', '.')
+        with pytest.raises(OSError, match="No files could be found or downloaded."):
+            get_bucket_files("*.nc", ".")
 
-    @mock.patch('satpy.demo._google_cloud_platform.gcsfs', None)
+    @mock.patch("satpy.demo._google_cloud_platform.gcsfs", None)
     def test_no_gcsfs(self):
         """Test that 'gcsfs' is required."""
         from satpy.demo._google_cloud_platform import get_bucket_files
-        self.assertRaises(RuntimeError, get_bucket_files, '*.nc', '.')
+        with pytest.raises(RuntimeError):
+            get_bucket_files("*.nc", ".")
 
 
 class TestAHIDemoDownload:
     """Test the AHI demo data download."""
 
-    @mock.patch.dict(sys.modules, {'s3fs': mock.MagicMock()})
+    @mock.patch.dict(sys.modules, {"s3fs": mock.MagicMock()})
     def test_ahi_full_download(self):
         """Test that the himawari download works as expected."""
         from tempfile import gettempdir
@@ -197,7 +206,7 @@ class TestAHIDemoDownload:
         files = download_typhoon_surigae_ahi(base_dir=gettempdir())
         assert len(files) == 160
 
-    @mock.patch.dict(sys.modules, {'s3fs': mock.MagicMock()})
+    @mock.patch.dict(sys.modules, {"s3fs": mock.MagicMock()})
     def test_ahi_partial_download(self):
         """Test that the himawari download works as expected."""
         from tempfile import gettempdir
@@ -244,11 +253,12 @@ class _FakeRequest:
 
     requests_log: list[str] = []
 
-    def __init__(self, url, stream=None):
+    def __init__(self, url, stream=None, timeout=None):
         self._filename = os.path.basename(url)
         self.headers = {}
         self.requests_log.append(url)
         del stream  # just mimicking requests 'get'
+        del timeout  # just mimicking requests 'get'
 
     def __enter__(self):
         return self
@@ -274,7 +284,7 @@ class _FakeRequest:
             x = bytes_io.read(chunk_size)
 
 
-@mock.patch('satpy.demo.utils.requests')
+@mock.patch("satpy.demo.utils.requests")
 class TestVIIRSSDRDemoDownload:
     """Test VIIRS SDR downloading."""
 
@@ -284,20 +294,20 @@ class TestVIIRSSDRDemoDownload:
                          "SVDNB")
     ALL_GEO_PREFIXES = ("GITCO", "GMTCO", "GDNBO")
 
-    def test_download(self, _requests, tmpdir):
+    def test_download(self, requests, tmpdir):
         """Test downloading VIIRS SDR data."""
         from satpy.demo import get_viirs_sdr_20170128_1229
-        _requests.get.side_effect = _FakeRequest
+        requests.get.side_effect = _FakeRequest
         with mock_filesystem():
             files = get_viirs_sdr_20170128_1229(base_dir=str(tmpdir))
             assert len(files) == 10 * (16 + 5 + 1 + 3)  # 10 granules * (5 I bands + 16 M bands + 1 DNB + 3 geolocation)
             self._assert_bands_in_filenames_and_contents(self.ALL_BAND_PREFIXES + self.ALL_GEO_PREFIXES, files, 10)
 
-    def test_do_not_download_the_files_twice(self, _requests, tmpdir):
+    def test_do_not_download_the_files_twice(self, requests, tmpdir):
         """Test re-downloading VIIRS SDR data."""
         from satpy.demo import get_viirs_sdr_20170128_1229
         get_mock = mock.MagicMock()
-        _requests.get.return_value.__enter__ = get_mock
+        requests.get.return_value.__enter__ = get_mock
         with mock_filesystem():
             files = get_viirs_sdr_20170128_1229(base_dir=str(tmpdir))
             new_files = get_viirs_sdr_20170128_1229(base_dir=str(tmpdir))
@@ -307,21 +317,21 @@ class TestVIIRSSDRDemoDownload:
         assert get_mock.call_count == total_num_files
         assert new_files == files
 
-    def test_download_channels_num_granules_im(self, _requests, tmpdir):
+    def test_download_channels_num_granules_im(self, requests, tmpdir):
         """Test downloading VIIRS SDR I/M data with select granules."""
         from satpy.demo import get_viirs_sdr_20170128_1229
-        _requests.get.side_effect = _FakeRequest
+        requests.get.side_effect = _FakeRequest
         with mock_filesystem():
             files = get_viirs_sdr_20170128_1229(base_dir=str(tmpdir),
                                                 channels=("I01", "M01"))
             assert len(files) == 10 * (1 + 1 + 2)  # 10 granules * (1 I band + 1 M band + 2 geolocation)
             self._assert_bands_in_filenames_and_contents(("SVI01", "SVM01", "GITCO", "GMTCO"), files, 10)
 
-    def test_download_channels_num_granules_im_twice(self, _requests, tmpdir):
+    def test_download_channels_num_granules_im_twice(self, requests, tmpdir):
         """Test re-downloading VIIRS SDR I/M data with select granules."""
         from satpy.demo import get_viirs_sdr_20170128_1229
         get_mock = mock.MagicMock()
-        _requests.get.return_value.__enter__ = get_mock
+        requests.get.return_value.__enter__ = get_mock
         with mock_filesystem():
             files = get_viirs_sdr_20170128_1229(base_dir=str(tmpdir),
                                                 channels=("I01", "M01"))
@@ -334,10 +344,10 @@ class TestVIIRSSDRDemoDownload:
             assert len(files) == 2 * (1 + 1 + 2)  # 2 granules * (1 I band + 1 M band + 2 geolocation)
             assert get_mock.call_count == num_first_batch
 
-    def test_download_channels_num_granules_dnb(self, _requests, tmpdir):
+    def test_download_channels_num_granules_dnb(self, requests, tmpdir):
         """Test downloading and re-downloading VIIRS SDR DNB data with select granules."""
         from satpy.demo import get_viirs_sdr_20170128_1229
-        _requests.get.side_effect = _FakeRequest
+        requests.get.side_effect = _FakeRequest
         with mock_filesystem():
             files = get_viirs_sdr_20170128_1229(base_dir=str(tmpdir),
                                                 channels=("DNB",),
@@ -415,7 +425,7 @@ class TestSEVIRIHRITDemoDownload(unittest.TestCase):
         self.subdir = os.path.join(".", "seviri_hrit", "20180228_1500")
         self.files = generate_subset_of_filenames(base_dir=self.subdir)
 
-        self.patcher = mock.patch('satpy.demo.utils.requests.get', autospec=True)
+        self.patcher = mock.patch("satpy.demo.utils.requests.get", autospec=True)
         self.get_mock = self.patcher.start()
 
         _FakeRequest.requests_log = []
@@ -450,12 +460,12 @@ class TestSEVIRIHRITDemoDownload(unittest.TestCase):
         with mock_filesystem():
             files = download_seviri_hrit_20180228_1500(subset={"HRV": [1, 2, 3], "IR_108": [1, 2], "EPI": None})
             assert set(files) == set(os.path.join(self.subdir, filename) for filename in [
-                'H-000-MSG4__-MSG4________-_________-EPI______-201802281500-__',
-                'H-000-MSG4__-MSG4________-HRV______-000001___-201802281500-__',
-                'H-000-MSG4__-MSG4________-HRV______-000002___-201802281500-__',
-                'H-000-MSG4__-MSG4________-HRV______-000003___-201802281500-__',
-                'H-000-MSG4__-MSG4________-IR_108___-000001___-201802281500-__',
-                'H-000-MSG4__-MSG4________-IR_108___-000002___-201802281500-__',
+                "H-000-MSG4__-MSG4________-_________-EPI______-201802281500-__",
+                "H-000-MSG4__-MSG4________-HRV______-000001___-201802281500-__",
+                "H-000-MSG4__-MSG4________-HRV______-000002___-201802281500-__",
+                "H-000-MSG4__-MSG4________-HRV______-000003___-201802281500-__",
+                "H-000-MSG4__-MSG4________-IR_108___-000001___-201802281500-__",
+                "H-000-MSG4__-MSG4________-IR_108___-000002___-201802281500-__",
             ])
 
     def test_do_not_download_same_file_twice(self):
